@@ -9,6 +9,7 @@ from cms.utils.helpers import find_placeholder_relation
 import django
 from django.conf import settings
 from django.contrib import admin, messages
+from django.contrib.admin.models import LogEntry, CHANGE
 from django.contrib.admin.options import IncorrectLookupParameters
 from django.contrib.admin.util import get_deleted_objects
 from django.contrib.contenttypes.models import ContentType
@@ -1063,6 +1064,13 @@ class PageAdmin(ModelAdmin):
                         messages.info(request, _('The page "%s" was successfully unpublished') % page)
                     else:
                         messages.info(request, _('The page "%s" was successfully published') % page)
+                    LogEntry.objects.log_action(
+                        user_id=request.user.id,
+                        content_type_id=ContentType.objects.get_for_model(Page).pk,
+                        object_id=page_id,
+                        object_repr=page.get_title(),
+                        action_flag=CHANGE,
+                    )
                 except RuntimeError, e:
                     messages.error(request, e.message)
             return admin_utils.render_admin_menu_item(request, page)
@@ -1086,7 +1094,7 @@ class PageAdmin(ModelAdmin):
         """
         Get html for descendants of given page
         Used for lazy loading pages in change_list.js
-        
+
         Permission checks is done in admin_utils.get_admin_menu_item_context
         which is called by admin_utils.render_admin_menu_item.
         """
@@ -1145,9 +1153,11 @@ class PageAdmin(ModelAdmin):
             raise Http404()
 
         # Sanity check to make sure we're not getting bogus values from JavaScript:
-        if not language or not language in [lang[0] for lang in settings.LANGUAGES]:
-            return HttpResponseBadRequest(_("Language must be set to a supported language!"))
-
+        if settings.USE_I18N:
+            if not language or not language in [lang[0] for lang in settings.LANGUAGES]:
+                return HttpResponseBadRequest(_("Language must be set to a supported language!"))
+        else:
+            language = settings.LANGUAGE_CODE
         plugin = CMSPlugin(language=language, plugin_type=plugin_type, position=position, placeholder=placeholder)
 
         if parent:
