@@ -1,15 +1,22 @@
 # -*- coding: utf-8 -*-
+from distutils.version import LooseVersion
+import re
+
+from cms.utils import get_cms_setting
 from cms.exceptions import SubClassNeededError, Deprecated
 from cms.models import CMSPlugin
+import django
 from django import forms
+from django.core.urlresolvers import reverse
 from django.conf import settings
 from django.contrib import admin
 from django.core.exceptions import ImproperlyConfigured
-from django.db.models.options import get_verbose_name
 from django.forms.models import ModelForm
 from django.utils.encoding import smart_str
 from django.utils.translation import ugettext_lazy as _
 
+DJANGO_1_4 = LooseVersion(django.get_version()) < LooseVersion('1.5')
+
 class CMSPluginBaseMetaclass(forms.MediaDefiningClass):
     """
     Ensure the CMSPlugin subclasses have sane values and set some defaults if 
@@ -50,7 +57,7 @@ class CMSPluginBaseMetaclass(forms.MediaDefiningClass):
             advanced_fields = []
             for f in new_plugin.model._meta.fields:
                 if not f.auto_created and f.editable:
-                    if hasattr(f,'advanced'): 
+                    if hasattr(f, 'advanced'):
                         advanced_fields.append(f.name)
                     else: basic_fields.append(f.name)
             if advanced_fields:
@@ -62,57 +69,66 @@ class CMSPluginBaseMetaclass(forms.MediaDefiningClass):
                         }
                     ),
                     (
-                        _('Advanced options'), 
+                        _('Advanced options'),
                         {
-                            'fields' : advanced_fields, 
+                            'fields' : advanced_fields,
                             'classes' : ('collapse',)
                         }
                     )
                 ]
         # Set default name
         if not new_plugin.name:
-            new_plugin.name = get_verbose_name(new_plugin.__name__)
+            new_plugin.name = re.sub("([a-z])([A-Z])", "\g<1> \g<2>", name)
         return new_plugin
 
 
 class CMSPluginBase(admin.ModelAdmin):
     __metaclass__ = CMSPluginBaseMetaclass
-    
+
     name = ""
-    
+
     form = None
     change_form_template = "admin/cms/page/plugin_change_form.html"
+    frontend_edit_template = 'cms/toolbar/placeholder_wrapper.html'
     # Should the plugin be rendered in the admin?
-    admin_preview = True 
-    
+    admin_preview = False
+
     render_template = None
+
     # Should the plugin be rendered at all, or doesn't it have any output?
-    render_plugin = True 
+    render_plugin = True
+
     model = CMSPlugin
     text_enabled = False
     page_only = False
-    
+
+    allow_children = False
+    child_classes = None
+
     opts = {}
     module = None #track in which module/application belongs
-    
-    def __init__(self, model=None,  admin_site=None):
+
+    def __init__(self, model=None, admin_site=None):
         if admin_site:
             super(CMSPluginBase, self).__init__(self.model, admin_site)
-        
+
         self.object_successfully_changed = False
-        
+
         # variables will be overwritten in edit_view, so we got required
         self.cms_plugin_instance = None
         self.placeholder = None
         self.page = None
 
+
     def render(self, context, instance, placeholder):
-        raise NotImplementedError("render needs to be implemented")
-    
+        context['instance'] = instance
+        context['placeholder'] = placeholder
+        return context
+
     @property
     def parent(self):
         return self.cms_plugin_instance.parent
-    
+
     def render_change_form(self, request, context, add=False, change=False, form_url='', obj=None):
         """
         We just need the popup interface here
@@ -121,11 +137,11 @@ class CMSPluginBase(admin.ModelAdmin):
             'preview': not "no_preview" in request.GET,
             'is_popup': True,
             'plugin': self.cms_plugin_instance,
-            'CMS_MEDIA_URL': settings.CMS_MEDIA_URL,
+            'CMS_MEDIA_URL': get_cms_setting('MEDIA_URL'),
         })
-        
+
         return super(CMSPluginBase, self).render_change_form(request, context, add, change, form_url, obj)
-        
+
     def has_add_permission(self, request, *args, **kwargs):
         """Permission handling change - if user is allowed to change the page
         he must be also allowed to add/change/delete plugins..
@@ -135,7 +151,7 @@ class CMSPluginBase(admin.ModelAdmin):
         """
         return self.cms_plugin_instance.has_change_permission(request)
     has_delete_permission = has_change_permission = has_add_permission
-    
+
     def save_model(self, request, obj, form, change):
         """
         Override original method, and add some attributes to obj
@@ -144,7 +160,7 @@ class CMSPluginBase(admin.ModelAdmin):
         Attributes from cms_plugin_instance have to be assigned to object, if
         is cms_plugin_instance attribute available.
         """
-        
+
         if getattr(self, "cms_plugin_instance"):
             # assign stuff to object
             fields = self.cms_plugin_instance._meta.fields
@@ -153,12 +169,12 @@ class CMSPluginBase(admin.ModelAdmin):
                 # subclassing cms_plugin_instance (one to one relation)
                 value = getattr(self.cms_plugin_instance, field.name)
                 setattr(obj, field.name, value)
-        
+
         # remember the saved object
         self.saved_object = obj
-        
+
         return super(CMSPluginBase, self).save_model(request, obj, form, change)
-    
+
     def response_change(self, request, obj):
         """
         Just set a flag, so we know something was changed, and can make
@@ -167,15 +183,20 @@ class CMSPluginBase(admin.ModelAdmin):
         """
         self.object_successfully_changed = True
         return super(CMSPluginBase, self).response_change(request, obj)
-    
-    def response_add(self, request, obj):
+
+    def response_add(self, request, obj, **kwargs):
         """
         Just set a flag, so we know something was changed, and can make
         new version if reversion installed.
         New version will be created in admin.views.edit_plugin
         """
         self.object_successfully_changed = True
-        return super(CMSPluginBase, self).response_add(request, obj)
+        if not DJANGO_1_4:
+            post_url_continue = reverse('admin:cms_page_edit_plugin',
+                    args=(obj._get_pk_val(),),
+                    current_app=self.admin_site.name)
+            kwargs.setdefault('post_url_continue', post_url_continue)
+        return super(CMSPluginBase, self).response_add(request, obj, **kwargs)
 
     def log_addition(self, request, object):
         pass
@@ -185,7 +206,7 @@ class CMSPluginBase(admin.ModelAdmin):
 
     def log_deletion(self, request, object, object_repr):
         pass
-                
+
     def icon_src(self, instance):
         """
         Overwrite this if text_enabled = True
@@ -194,7 +215,7 @@ class CMSPluginBase(admin.ModelAdmin):
         plugin instance in a text editor.
         """
         return ""
- 
+
     def icon_alt(self, instance):
         """
         Overwrite this if necessary if text_enabled = True
@@ -202,25 +223,33 @@ class CMSPluginBase(admin.ModelAdmin):
         the plugin object in a text editor.
         """
         return "%s - %s" % (unicode(self.name), unicode(instance))
-    
+
+    def get_child_classes(self, slot, page):
+        from cms.plugin_pool import plugin_pool
+        if self.child_classes:
+            return self.child_classes
+        else:
+            installed_plugins = plugin_pool.get_all_plugins(slot, page)
+            return [cls.__name__ for cls in installed_plugins]
+
     def __repr__(self):
         return smart_str(self.name)
-    
+
     def __unicode__(self):
         return self.name
-    
+
     #===========================================================================
     # Deprecated APIs
     #===========================================================================
-    
+
     @property
     def pluginmedia(self):
         raise Deprecated(
             "CMSPluginBase.pluginmedia is deprecated in favor of django-sekizai"
         )
-        
-    
+
+
     def get_plugin_media(self, request, context, plugin):
         raise Deprecated(
             "CMSPluginBase.get_plugin_media is deprecated in favor of django-sekizai"
-        )
\ No newline at end of file
+        )
