@@ -1,6 +1,8 @@
 from __future__ import with_statement
+from django.contrib.auth.models import Permission
 from cms.api import create_page
 from cms.apphook_pool import apphook_pool
+from cms.models import PagePermission
 from cms.test_utils.testcases import SettingsOverrideTestCase
 from cms.test_utils.util.context_managers import SettingsOverride
 from cms.views import _handle_no_page, details
@@ -15,9 +17,10 @@ APP_MODULE = "cms.test_utils.project.sampleapp.cms_app"
 
 
 class ViewTests(SettingsOverrideTestCase):
-    urls = 'cms.test_utils.project.urls_for_apphook_tests'
-    settings_overrides = {'CMS_MODERATOR': False}
-    
+    urls = 'cms.test_utils.project.urls'
+
+    settings_overrides = {'CMS_PERMISSION': True}
+
     def setUp(self):
         clear_url_caches()
     
@@ -29,23 +32,11 @@ class ViewTests(SettingsOverrideTestCase):
         slug = ''
         self.assertRaises(Http404, _handle_no_page, request, slug)
         with SettingsOverride(DEBUG=True):
-            request = self.get_request('/')
+            request = self.get_request('/en/')
             slug = ''
             response = _handle_no_page(request, slug)
             self.assertEqual(response.status_code, 200)
-            
-    def test_language_fallback(self):
-        """
-        Test language fallbacks in details view
-        """
-        create_page("page", "nav_playground.html", "en", published=True)
-        request = self.get_request('/', 'de')
-        response = details(request, '')
-        self.assertEqual(response.status_code, 302)
-        self.assertEqual(response['Location'], '/en/')
-        with SettingsOverride(CMS_LANGUAGE_FALLBACK=False):
-            self.assertRaises(Http404, details, request, '')
-    
+
     def test_apphook_not_hooked(self):
         """
         Test details view when apphook pool has apphooks, but they're not
@@ -59,7 +50,7 @@ class ViewTests(SettingsOverrideTestCase):
         create_page("page2", "nav_playground.html", "en", published=True)
         with SettingsOverride(CMS_APPHOOKS=apphooks):
             apphook_pool.clear()
-            response = self.client.get('/')
+            response = self.client.get('/en/')
             self.assertEqual(response.status_code, 200)
             apphook_pool.clear()
     
@@ -70,7 +61,7 @@ class ViewTests(SettingsOverrideTestCase):
                           redirect=redirect_one)
         url = one.get_absolute_url()
         request = self.get_request(url)
-        response = details(request, url.strip('/'))
+        response = details(request,one.get_path("en"))
         self.assertEqual(response.status_code, 302)
         self.assertEqual(response['Location'], redirect_one)
         
@@ -84,7 +75,7 @@ class ViewTests(SettingsOverrideTestCase):
                           published=True, redirect=redirect_two)
         url = two.get_absolute_url()
         request = self.get_request(url)
-        response = details(request, url.strip('/'))
+        response = details(request, two.get_path())
         self.assertEqual(response.status_code, 302)
         self.assertEqual(response['Location'], '/en/')
         
@@ -96,7 +87,7 @@ class ViewTests(SettingsOverrideTestCase):
                           redirect=redirect_one)
         three = create_page("three", "nav_playground.html", "en", parent=one,
                             published=True, redirect=redirect_three)
-        url = three.get_absolute_url()
+        url = three.get_slug()
         request = self.get_request(url)
         response = details(request, url.strip('/'))
         self.assertEqual(response.status_code, 302)
@@ -107,26 +98,51 @@ class ViewTests(SettingsOverrideTestCase):
                           redirect='/')
         url = one.get_absolute_url()
         request = self.get_request(url)
-        response = details(request, url.strip('/'))
-        self.assertEqual(response.status_code, HttpResponse.status_code)
+        response = details(request, one.get_path())
+        self.assertEqual(response.status_code, 200)
         
     def test_redirect_to_self_with_host(self):
         one = create_page("one", "nav_playground.html", "en", published=True,
-                          redirect='http://testserver/')
+                          redirect='http://testserver/en/')
         url = one.get_absolute_url()
         request = self.get_request(url)
-        response = details(request, url.strip('/'))
-        self.assertEqual(response.status_code, HttpResponse.status_code)
+        response = details(request, one.get_path())
+        self.assertEqual(response.status_code, 200)
     
     def test_login_required(self):
         create_page("page", "nav_playground.html", "en", published=True,
                          login_required=True)
-        request = self.get_request('/')
+        request = self.get_request('/en/')
         response = details(request, '')
         self.assertEqual(response.status_code, 302)
         self.assertEqual(response['Location'], '%s?next=/en/' % settings.LOGIN_URL)
-        with SettingsOverride(i18n_installed=False):
+        with SettingsOverride(USE_I18N=False):
             request = self.get_request('/')
             response = details(request, '')
             self.assertEqual(response.status_code, 302)
             self.assertEqual(response['Location'], '%s?next=/' % settings.LOGIN_URL)
+
+    def test_edit_permission(self):
+        page = create_page("page", "nav_playground.html", "en", published=True)
+
+        # Anon user
+        response = self.client.get("/en/?edit")
+        self.assertContains(response, "'edit_mode': false,", 1, 200)
+
+        # Superuser
+        user = self.get_superuser()
+        self.client.login(username=user.username, password=user.username)
+        response = self.client.get("/en/?edit")
+        self.assertContains(response, "'edit_mode': true,", 1, 200)
+
+        # Admin but with no permission
+        user = self.get_staff_user_with_no_permissions()
+        user.user_permissions.add(Permission.objects.get(codename='change_page'))
+
+        self.client.login(username=user.username, password=user.username)
+        response = self.client.get("/en/?edit")
+        self.assertContains(response, "'edit_mode': false,", 1, 200)
+
+        PagePermission.objects.create(can_change=True, user=user, page=page)
+        response = self.client.get("/en/?edit")
+        self.assertContains(response, "'edit_mode': true,", 1, 200)
